.. _all-salt.queues:

=============
queue modules
=============

.. currentmodule:: salt.queues

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    pgjsonb_queue
    sqlite_queue
